Action

Struct Action 

pub struct Action<R, TH, B>
where R: RegisterTask<TH>, TH: TaskHandle, B: Behavior,
{ /* private fields */ }
Action leaf node that bridges the synchronous tick interface and the executor.

Action uses the user-provided Behavior to create an ActionTask, registers it through RegisterTask, and reports progress through TickStatus on later ticks.

See the runtime execution chapter in the book for a more detailed explanation: https://beetry.pages.dev/runtime/execution.html.

Implementations

Source

impl<R, TH, B> Action<R, TH, B>
where R: RegisterTask<TH>, TH: TaskHandle, B: Behavior,

pub fn new(behavior: B, registry: Arc<R>, abort_poll_interval: Duration) -> Self